@@ -31,6 +31,7 @@ if not os.path.isdir(CACHE_DIR):
     "--urls",
     metavar="URLS",
     help="Url from Qobuz, Tidal, SoundCloud, or Deezer",
+    multiple=True,
 )
 @click.option(
     "-q",
@@ -62,6 +63,9 @@ def cli(ctx, **kwargs):
         logger.setLevel("DEBUG")
         logger.debug("Starting debug log")
 
+    if ctx.invoked_subcommand not in {None, "lastfm", "search", "disover", "config"}:
+        return
+
     config = Config()
 
     if ctx.invoked_subcommand == "config":
@@ -81,9 +85,11 @@ def cli(ctx, **kwargs):
 
     if kwargs["no_db"]:
         config.session["database"]["enabled"] = False
+
     if kwargs["convert"]:
         config.session["conversion"]["enabled"] = True
         config.session["conversion"]["codec"] = kwargs["convert"]
+
     if kwargs["quality"] is not None:
         quality = int(kwargs["quality"])
         if quality not in range(5):
@@ -278,6 +284,7 @@ def lastfm(ctx, source, url):
 @click.pass_context
 def config(ctx, **kwargs):
     """Manage the streamrip configuration file."""
+    global config
     if kwargs["reset"]:
         config.reset()
 
@@ -321,6 +328,83 @@ def config(ctx, **kwargs):
         click.secho("Credentials saved to config.", fg="green")
 
 
+@cli.command()
+@click.option(
+    "-sr", "--sampling-rate", help="Downsample the tracks to this rate, in Hz."
+)
+@click.option("-bd", "--bit-depth", help="Downsample the tracks to this bit depth.")
+@click.option(
+    "-k",
+    "--keep-source",
+    is_flag=True,
+    help="Do not delete the old file after conversion.",
+)
+@click.argument("CODEC")
+@click.argument("PATH")
+@click.pass_context
+def convert(ctx, **kwargs):
+    from . import converter
+    import concurrent.futures
+    from tqdm import tqdm
+
+    codec_map = {
+        "FLAC": converter.FLAC,
+        "ALAC": converter.ALAC,
+        "OPUS": converter.OPUS,
+        "MP3": converter.LAME,
+        "AAC": converter.AAC,
+    }
+
+    codec = kwargs.get("codec").upper()
+    assert codec in codec_map.keys(), f"Invalid codec {codec}"
+
+    if s := kwargs.get("sampling_rate"):
+        sampling_rate = int(s)
+    else:
+        sampling_rate = None
+
+    if s := kwargs.get("bit_depth"):
+        bit_depth = int(s)
+    else:
+        bit_depth = None
+
+    converter_args = {
+        "sampling_rate": sampling_rate,
+        "bit_depth": bit_depth,
+        "remove_source": not kwargs.get("keep_source", False),
+    }
+    if os.path.isdir(kwargs["path"]):
+        dirname = kwargs["path"]
+        with concurrent.futures.ThreadPoolExecutor() as executor:
+            futures = []
+            audio_extensions = ("flac", "m4a", "aac", "opus", "mp3", "ogg")
+            audio_files = (
+                f
+                for f in os.listdir(kwargs["path"])
+                if any(f.endswith(ext) for ext in audio_extensions)
+            )
+            for file in audio_files:
+                futures.append(
+                    executor.submit(
+                        codec_map[codec](
+                            filename=os.path.join(dirname, file), **converter_args
+                        ).convert
+                    )
+                )
+            for future in tqdm(
+                concurrent.futures.as_completed(futures),
+                total=len(futures),
+                desc="Converting",
+            ):
+                # Only show loading bar
+                pass
+
+    elif os.path.isfile(kwargs["path"]):
+        codec_map[codec](filename=kwargs["path"], **converter_args).convert()
+    else:
+        click.secho(f"File {kwargs['path']} does not exist.", fg="red")
+
+
 def none_chosen():
     """Print message if nothing was chosen."""
     click.secho("No items chosen, exiting.", fg="bright_red")
