@@ -26,13 +26,13 @@ from .config import Config
 from .constants import (
     CONFIG_PATH,
     DB_PATH,
+    DEEZER_DYNAMIC_LINK_REGEX,
     LASTFM_URL_REGEX,
     MEDIA_TYPES,
     QOBUZ_INTERPRETER_URL_REGEX,
     SOUNDCLOUD_URL_REGEX,
     URL_REGEX,
     YOUTUBE_URL_REGEX,
-    DEEZER_DYNAMIC_LINK_REGEX,
 )
 from .db import MusicDB
 from .exceptions import (
@@ -43,7 +43,7 @@ from .exceptions import (
     ParsingError,
 )
 from .tracklists import Album, Artist, Label, Playlist, Tracklist
-from .utils import extract_interpreter_url, extract_deezer_dynamic_link
+from .utils import extract_deezer_dynamic_link, extract_interpreter_url
 
 logger = logging.getLogger("streamrip")
 
@@ -111,7 +111,7 @@ class MusicDL(list):
         else:
             self.db = []
 
-    def handle_urls(self, url: str):
+    def handle_urls(self, urls):
         """Download a url.
 
         :param url:
@@ -119,6 +119,13 @@ class MusicDL(list):
         :raises InvalidSourceError
         :raises ParsingError
         """
+        if isinstance(urls, str):
+            url = urls
+        elif isinstance(urls, tuple):
+            url = " ".join(urls)
+        else:
+            raise Exception(f"Urls has invalid type {type(urls)}")
+
         # youtube is handled by youtube-dl, so much of the
         # processing is not necessary
         youtube_urls = self.youtube_url_parse.findall(url)
@@ -133,7 +140,7 @@ class MusicDL(list):
                     f"command. See {click.style('rip lastfm --help', fg='yellow')}."
                 )
             else:
-                message = url
+                message = f"Cannot find urls in text: {url}"
 
             raise ParsingError(message)
 
@@ -242,7 +249,7 @@ class MusicDL(list):
             if not (isinstance(item, Tracklist) and item.loaded):
                 logger.debug("Loading metadata")
                 try:
-                    item.load_meta()
+                    item.load_meta(**arguments)
                 except NonStreamable:
                     click.secho(f"{item!s} is not available, skipping.", fg="red")
                     continue
@@ -366,7 +373,6 @@ class MusicDL(list):
 
         :param urls:
         """
-
         # Available keys: ['artist', 'title']
         QUERY_FORMAT: Dict[str, str] = {
             "tidal": "{title}",
@@ -637,7 +643,6 @@ class MusicDL(list):
         :type url: str
         :rtype: Tuple[str, list]
         """
-
         logger.debug("Fetching lastfm playlist")
 
         info = []
