@@ -19,7 +19,7 @@ from .constants import (
     TRACK_KEYS,
 )
 from .exceptions import InvalidContainerError, InvalidSourceError
-from .utils import get_quality_id, safe_get, tidal_cover_url
+from .utils import get_quality_id, safe_get, tidal_cover_url, get_cover_urls
 
 logger = logging.getLogger("streamrip")
 
@@ -151,8 +151,7 @@ class TrackMetadata:
 
             # Non-embedded information
             self.version = resp.get("version")
-            self.cover_urls = OrderedDict(resp["image"])
-            self.cover_urls["original"] = self.cover_urls["large"].replace("600", "org")
+            self.cover_urls = get_cover_urls(resp, self.__source)
             self.streamable = resp.get("streamable", False)
             self.bit_depth = resp.get("maximum_bit_depth")
             self.sampling_rate = resp.get("maximum_sampling_rate")
@@ -177,13 +176,7 @@ class TrackMetadata:
             # non-embedded
             self.explicit = resp.get("explicit", False)
             # 80, 160, 320, 640, 1280
-            uuid = resp.get("cover")
-            self.cover_urls = OrderedDict(
-                {
-                    sk: tidal_cover_url(uuid, size)
-                    for sk, size in zip(COVER_SIZES, (160, 320, 640, 1280))
-                }
-            )
+            self.cover_urls = get_cover_urls(resp, self.__source)
             self.streamable = resp.get("allowStreaming", False)
 
             if q := resp.get("audioQuality"):  # for album entries in single tracks
@@ -205,15 +198,7 @@ class TrackMetadata:
             self.explicit = bool(resp.get("parental_warning"))
             self.quality = 2
             self.bit_depth = 16
-            self.cover_urls = OrderedDict(
-                {
-                    sk: resp.get(rk)  # size key, resp key
-                    for sk, rk in zip(
-                        COVER_SIZES,
-                        ("cover", "cover_medium", "cover_large", "cover_xl"),
-                    )
-                }
-            )
+            self.cover_urls = get_cover_urls(resp, self.__source)
             self.sampling_rate = 44100
             self.streamable = True
 
