@@ -8,6 +8,7 @@ import os
 import re
 from string import Formatter
 from typing import Dict, Hashable, Optional, Tuple, Union
+from collections import OrderedDict
 
 import click
 import requests
@@ -15,7 +16,7 @@ from pathvalidate import sanitize_filename
 from requests.packages import urllib3
 from tqdm import tqdm
 
-from .constants import AGENT, TIDAL_COVER_URL
+from .constants import AGENT, TIDAL_COVER_URL, COVER_SIZES
 from .exceptions import InvalidQuality, InvalidSourceError, NonStreamable
 
 urllib3.disable_warnings()
@@ -112,6 +113,12 @@ def get_quality_id(bit_depth: Optional[int], sampling_rate: Optional[int]):
 def get_stats_from_quality(
     quality_id: int,
 ) -> Tuple[Optional[int], Optional[int]]:
+    """Get bit depth and sampling rate based on the quality id.
+
+    :param quality_id:
+    :type quality_id: int
+    :rtype: Tuple[Optional[int], Optional[int]]
+    """
     if quality_id <= 1:
         return (None, None)
     elif quality_id == 2:
@@ -337,10 +344,18 @@ def extract_interpreter_url(url: str) -> str:
     )
 
 
-deezer_id_link_regex = re.compile(r"https://www\.deezer\.com/[a-z]{2}/(album|artist|playlist|track)/(\d+)")
+deezer_id_link_regex = re.compile(
+    r"https://www\.deezer\.com/[a-z]{2}/(album|artist|playlist|track)/(\d+)"
+)
 
 
 def extract_deezer_dynamic_link(url: str) -> Tuple[str, str]:
+    """Extract a deezer url that includes an ID from a deezer.page.link url.
+
+    :param url:
+    :type url: str
+    :rtype: Tuple[str, str]
+    """
     session = gen_threadsafe_session({"User-Agent": AGENT})
     r = session.get(url)
     match = deezer_id_link_regex.search(r.text)
@@ -370,22 +385,34 @@ def get_container(quality: int, source: str) -> str:
     return "MP3"
 
 
-class Version:
-    def __init__(self, version: str):
-        self.value = tuple(map(int, version.split(".")))
+def get_cover_urls(resp: dict, source: str) -> dict:
+    if source == "qobuz":
+        cover_urls = OrderedDict(resp["image"])
+        cover_urls["original"] = cover_urls["large"].replace("600", "org")
+        return cover_urls
 
-    def __gt__(self, other) -> bool:
-        assert isinstance(other, Version)
-        for v1, v2 in zip(self.value, other.value):
-            if v1 > v2:
-                return True
-            elif v1 < v2:
-                return False
-        return False
+    if source == "tidal":
+        uuid = resp["cover"]
+        return OrderedDict(
+            {
+                sk: tidal_cover_url(uuid, size)
+                for sk, size in zip(COVER_SIZES, (160, 320, 640, 1280))
+            }
+        )
 
-    def __lt__(self, other) -> bool:
-        return not self.__gt__(other) and not self.__eq__(other)
+    if source == "deezer":
+        cover_urls = OrderedDict(
+            {
+                sk: resp.get(rk)  # size key, resp key
+                for sk, rk in zip(
+                    COVER_SIZES,
+                    ("cover", "cover_medium", "cover_large", "cover_xl"),
+                )
+            }
+        )
+        if cover_urls["large"] is None and resp.get("cover_big") is not None:
+            cover_urls["large"] = resp["cover_big"]
 
-    def __eq__(self, other) -> bool:
-        assert isinstance(other, Version)
-        return all(v1 == v2 for v1, v2 in zip(self.value, other.value))
+        return cover_urls
+
+    raise InvalidSourceError(source)
